## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 4;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           python-typer
Version:        0.10.0
Release:        %autorelease
Summary:        Build great CLIs; easy to code; based on Python type hints

# SPDX
License:        MIT
URL:            https://typer.tiangolo.com/
Source:         https://github.com/tiangolo/typer/archive/%{version}/typer-%{version}.tar.gz

# Allow flit_core 3.x and later
#
# This is downstream-only because upstream switches to pdm-backend in 0.11.0.
Patch:          0001-Allow-flit_core-3.x-and-later.patch

BuildArch:      noarch

BuildRequires:  python3-devel

# Since the test extra contains overly-strict version bounds and many unwanted
# linting/coverage/typechecking/formatting dependencies
# (https://docs.fedoraproject.org/en-US/packaging-guidelines/Python/#_linters),
# we just list the few test dependencies we *do* want manually rather than
# trying to patch the extra. We preserve upstream’s lower bounds but remove
# upper bounds, as we must try to make do with what we have.
BuildRequires:  %{py3_dist shellingham} >= 1.3
BuildRequires:  %{py3_dist pytest} >= 4.4
BuildRequires:  %{py3_dist pytest-xdist} >= 1.32

%global common_description %{expand:
Typer is a library for building CLI applications that users will love using and
developers will love creating. Based on Python 3.6+ type hints.

The key features are:

  • Intuitive to write: Great editor support. Completion everywhere. Less time
    debugging. Designed to be easy to use and learn. Less time reading docs.
  • Easy to use: It’s easy to use for the final users. Automatic help, and
    automatic completion for all shells.
  • Short: Minimize code duplication. Multiple features from each parameter
    declaration. Fewer bugs.
  • Start simple: The simplest example adds only 2 lines of code to your app: 1
    import, 1 function call.
  • Grow large: Grow in complexity as much as you want, create arbitrarily
    complex trees of commands and groups of subcommands, with options and
    arguments.

Typer is FastAPI’s little sibling.

And it’s intended to be the FastAPI of CLIs.}

%description %{common_description}


%package -n     python3-typer
Summary:        %{summary}

%description -n python3-typer %{common_description}


%pyproject_extras_subpkg -n python3-typer all


%prep
%autosetup -n typer-%{version} -p1

# Remove bundled js-termynal 0.0.1; since we are not building documentation, we
# do this very bluntly:
rm -rvf docs/js docs/css


%generate_buildrequires
%pyproject_buildrequires -x all

%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files typer


%check
# See scripts/test.sh. We do not run the linters (scripts/lint.sh, i.e.,
# mypy/black/isort).
export TERMINAL_WIDTH=3000
export _TYPER_FORCE_DISABLE_TERMINAL=1

./scripts/test-files.sh

# Shell completion tests need us to be running under a supported shell, i.e.
# bash rather than sh. Unfortunately, shell detection with shellingham is so
# thorough we cannot fool it by any combination of:
#  - export SHELL=/bin/bash
#  - bash -c '%%pytest'
#  - %%check -p /bin/bash
# so we must simply skip the affected tests.
k="${k-}${k+ and }not test_show_completion"
k="${k-}${k+ and }not test_install_completion"
# These cannot find the typer package because the tests override PYTHONPATH.
ignore="${ignore-} --ignore=tests/test_tutorial/test_subcommands/test_tutorial001.py"
ignore="${ignore-} --ignore=tests/test_tutorial/test_subcommands/test_tutorial003.py"

mkdir _stub
cat > _stub/coverage.py <<'EOF'
from subprocess import run
from sys import argv, executable, exit
if len(argv) < 3 or argv[1] != "run":
    exit(f"Unsupported arguments: {argv!r}")
exit(run([executable] + argv[2:]).returncode)
EOF
export PYTHONPATH="${PWD}/_stub:%{buildroot}%{python3_sitelib}"

%pytest -k "${k-}" ${ignore-} -n auto -v -rs


%files -n python3-typer -f %{pyproject_files}
%license LICENSE
%doc CITATION.cff
%doc CONTRIBUTING.md
%doc README.md


%changelog
## START: Generated by rpmautospec
* Tue Nov 19 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.10.0-4
- Stub out "coverage run" well enough to drop the coverage dep.

* Tue Nov 19 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.10.0-2
- Remove an Obsoletes that has served its upgrade-path purpose

* Thu Mar 28 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.10.0-1
- Update to 0.10.0

* Thu Mar 28 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.9.4-1
- Update to 0.9.4

* Thu Mar 28 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.9.3-1
- Update to 0.9.3

* Thu Mar 28 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.9.2-1
- Update to 0.9.2
- Give up on patching out the dependency on the coverage module

* Thu Mar 28 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.9.1-1
- Update to 0.9.1
- New CITATION.cff file is packaged as documentation.

* Thu Mar 28 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.9.0-8
- Simplify patching pyproject.toml and handling test dependencies
- Drop unnecessary version-bounded BuildRequires on python-pytest-sugar,
  fixing failure to build from source with python-pytest-sugar 1.0.0.

* Fri May 12 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.9.0-4
- Revert "Work around no python-shellingham in EPEL9"

* Fri May 12 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.9.0-3
- Work around no python-shellingham in EPEL9
- Do not build a python3-typer+all metapackage

* Fri May 12 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.9.0-2
- Work around no python-pytest-sugar in EPEL9

* Tue May 02 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.9.0-1
- Update to 0.9.0 (close RHBZ#2192484)

* Mon May 01 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.8.0-1
- Update to 0.8.0 (close RHBZ#2192330)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Tue Jan 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.7.0-4
- Allow rich 13.x (fix RHBZ#2157866)

* Wed Dec 21 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.7.0-3
- Rely on PYTEST_XDIST_AUTO_NUM_WORKERS

* Sat Nov 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.7.0-2
- Add some environment variables from scripts/test.sh

* Sun Nov 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.7.0-1
- Update to 0.7.0 (close RHBZ#2140338)

* Sun Nov 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.6.1-3
- Confirm License is SPDX MIT

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jul 13 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.6.1-1
- Update to 0.6.1 (close RHBZ#2106487)

* Wed Jul 13 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.5.0-2
- Run tests in parallel with pytest-xdist

* Wed Jul 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.5.0-1
- Update to 0.5.0 (close RHBZ#2103375)

* Tue Jun 14 2022 Python Maint <python-maint@redhat.com> - 0.4.1-3
- Rebuilt for Python 3.11

* Fri Apr 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.4.1-2
- Patch out coverage analysis

* Thu Mar 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.4.1-1
- Update to 0.4.1 (close RHBZ#2070317)

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.4.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Dec 15 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.4.0-8
- Allow newer python-coverage, i.e., >=6.0

* Tue Oct 19 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.4.0-7
- Drop pytest-cov BR

* Tue Sep 28 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.4.0-6
- Drop the documentation subpackage entirely.

* Mon Sep 13 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.4.0-5
- Revert "Let pyproject-rpm-macros handle the license file"

* Mon Sep 13 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.4.0-4
- Drop BR on pyproject-rpm-macros, now implied by python3-devel

* Mon Sep 13 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.4.0-3
- Let pyproject-rpm-macros handle the license file

* Mon Sep 13 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.4.0-2
- Reduce macro indirection in the spec file

* Tue Aug 31 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.4.0-1
- Update to 0.4.0 (fix RHBZ#1977513)

* Wed Jun 30 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.3.2-4
- Remove reference to bug for out-of-date mkdocs-material

* Thu Jun 17 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.3.2-3
- Drop documentation dependency on mkdocs-material (RHBZ#1960274, comment 3)

* Wed May 26 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.3.2-2
- Unbundle js-termynal

* Tue May 25 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.3.2-1
- Initial package

## END: Generated by rpmautospec
